@@ -13,4 +13,4 @@ def format(xlab, ylab, show):
 def plot(x, y, xlab='$E$ / V', ylab='$i$ / A', fig=1, show=False):
     plt.figure(fig)
     plt.plot(x, y)
-    format_plot(xlab, ylab, show)
+    format(xlab, ylab, show)
